Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ToBreakpointFilter ¶
func ToBreakpointFilter(a *v1.PipelineActivity) *v1alpha1.LighthousePipelineFilter
ToBreakpointFilter converts the PipelineActivity to a filter for breakpoints
Types ¶
type Options ¶
type Options struct {
options.BaseOptions
BreakpointNames []string
KubeClient kubernetes.Interface
JXClient versioned.Interface
LHClient lhclient.Interface
Namespace string
Input input.Interface
Breakpoints []*v1alpha1.LighthouseBreakpoint
}
Options is the start of the data required to perform the operation. As new fields are added, add them here instead of referencing the cmd.Flags()
func NewCmdPipelineBreakpoint ¶
NewCmdPipelineBreakpoint creates the command
Click to show internal directories.
Click to hide internal directories.